@@ -14,7 +14,7 @@ class IGooglefontsConfiguration(Interface):
                               required=True,
                               default="")
                               
-  googlefontfamily = schema.Choice(title=u"Font", description=u"The Font that should be used.", values=['Cardo','Crimson Text', 'Cuprum',  'Droid Sans', 'Droid Sans Mono', 'Droid Serif',  'Inconsolata', 'Josefin Sans Std Light',   'Lobster', 'Molengo', 'Neuton', 'Nobile', 'Old Standard TT', 'PT Sans Narrow', 'PT Sans',   'Philosopher',   'Reenie Beanie',   'Tangerine',  'Vollkorn', 'Yanone Kaffeesatz', 'Cantarell'], default='Yanone Kaffeesatz')
+  googlefontfamily = schema.Choice(title=u"Font", description=u"The Font that should be used.", values=['Cantarell', 'Cardo','Crimson Text', 'Cuprum', 'Dawning of a New Day', 'Droid Sans Mono',  'Droid Sans', 'Droid Serif', 'EB Garamond', 'Gruppo',  'Inconsolata', 'Indie Flower', 'Josefin Sans Std Light', 'Lekton',   'Lobster', 'Molengo', 'Neuton', 'Nobile', 'Old Standard TT',   'Philosopher', 'PT Sans Narrow', 'PT Sans', 'Quattrocento Sans', 'Quattrocento',   'Reenie Beanie','Smythe', 'Special Elite', 'Sue Ellen Francisco',   'Tangerine', 'Terminal Dosis Light', 'The Girl Next Door',  'Vollkorn', 'Waiting for the Sunrise', 'Yanone Kaffeesatz'], default='Yanone Kaffeesatz')
 
   googlefontfamilysize = schema.ASCIILine(title=_(u"label_googlefontfamily", default=u'Size of the font'),
                               description=_(u"help_googlefontfamily", default=u''),
